==> volcano-model-v1beta1-6.1.0-sources.jar: io/fabric8/volcano/scheduling/v1beta1/PodGroupFluentImpl.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodGroupFluentImpl<A extends PodGroupFluent<A>> extends BaseFluent<A> implements PodGroupFluent<A>{
  public PodGroupFluentImpl() {
  }
  public PodGroupFluentImpl(PodGroup instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PodGroupSpecBuilder spec;
  private PodGroupStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PodGroupFluent.MetadataNested<A> withNewMetadata() {
    return new PodGroupFluentImpl.MetadataNestedImpl();
  }
  public PodGroupFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PodGroupFluentImpl.MetadataNestedImpl(item);
  }
  public PodGroupFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PodGroupFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PodGroupFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodGroupSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodGroupSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodGroupSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodGroupSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodGroupFluent.SpecNested<A> withNewSpec() {
    return new PodGroupFluentImpl.SpecNestedImpl();
  }
  public PodGroupFluent.SpecNested<A> withNewSpecLike(PodGroupSpec item) {
    return new PodGroupFluentImpl.SpecNestedImpl(item);
  }
  public PodGroupFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodGroupFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodGroupSpecBuilder().build());
  }
  public PodGroupFluent.SpecNested<A> editOrNewSpecLike(PodGroupSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodGroupStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PodGroupStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PodGroupStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PodGroupStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PodGroupFluent.StatusNested<A> withNewStatus() {
    return new PodGroupFluentImpl.StatusNestedImpl();
  }
  public PodGroupFluent.StatusNested<A> withNewStatusLike(PodGroupStatus item) {
    return new PodGroupFluentImpl.StatusNestedImpl(item);
  }
  public PodGroupFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PodGroupFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PodGroupStatusBuilder().build());
  }
  public PodGroupFluent.StatusNested<A> editOrNewStatusLike(PodGroupStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodGroupFluentImpl that = (PodGroupFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodGroupFluent.MetadataNested<N>> implements PodGroupFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PodGroupFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PodGroupSpecFluentImpl<PodGroupFluent.SpecNested<N>> implements PodGroupFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodGroupSpec item) {
      this.builder = new PodGroupSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodGroupSpecBuilder(this);
    }
    PodGroupSpecBuilder builder;
    public N and() {
      return (N) PodGroupFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PodGroupStatusFluentImpl<PodGroupFluent.StatusNested<N>> implements PodGroupFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PodGroupStatus item) {
      this.builder = new PodGroupStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PodGroupStatusBuilder(this);
    }
    PodGroupStatusBuilder builder;
    public N and() {
      return (N) PodGroupFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> volcano-model-v1beta1-6.7.2-sources.jar: io/fabric8/volcano/scheduling/v1beta1/PodGroupFluentImpl.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodGroupFluentImpl<A extends PodGroupFluent<A>> extends BaseFluent<A> implements PodGroupFluent<A>{
  public PodGroupFluentImpl() {
  }
  public PodGroupFluentImpl(PodGroup instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PodGroupSpecBuilder spec;
  private PodGroupStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PodGroupFluentImpl.MetadataNested<A> withNewMetadata() {
    return new PodGroupFluentImpl.MetadataNestedImpl();
  }
  public PodGroupFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PodGroupFluentImpl.MetadataNestedImpl(item);
  }
  public PodGroupFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PodGroupFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PodGroupFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodGroupSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodGroupSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodGroupSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodGroupSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodGroupFluentImpl.SpecNested<A> withNewSpec() {
    return new PodGroupFluentImpl.SpecNestedImpl();
  }
  public PodGroupFluentImpl.SpecNested<A> withNewSpecLike(PodGroupSpec item) {
    return new PodGroupFluentImpl.SpecNestedImpl(item);
  }
  public PodGroupFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodGroupFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodGroupSpecBuilder().build());
  }
  public PodGroupFluentImpl.SpecNested<A> editOrNewSpecLike(PodGroupSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodGroupStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PodGroupStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PodGroupStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PodGroupStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PodGroupFluentImpl.StatusNested<A> withNewStatus() {
    return new PodGroupFluentImpl.StatusNestedImpl();
  }
  public PodGroupFluentImpl.StatusNested<A> withNewStatusLike(PodGroupStatus item) {
    return new PodGroupFluentImpl.StatusNestedImpl(item);
  }
  public PodGroupFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PodGroupFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PodGroupStatusBuilder().build());
  }
  public PodGroupFluentImpl.StatusNested<A> editOrNewStatusLike(PodGroupStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodGroupFluentImpl that = (PodGroupFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodGroupFluentImpl.MetadataNested<N>> implements PodGroupFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PodGroupFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PodGroupSpecFluentImpl<PodGroupFluentImpl.SpecNested<N>> implements PodGroupFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodGroupSpec item) {
      this.builder = new PodGroupSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodGroupSpecBuilder(this);
    }
    PodGroupSpecBuilder builder;
    public N and() {
      return (N) PodGroupFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PodGroupStatusFluentImpl<PodGroupFluentImpl.StatusNested<N>> implements PodGroupFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PodGroupStatus item) {
      this.builder = new PodGroupStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PodGroupStatusBuilder(this);
    }
    PodGroupStatusBuilder builder;
    public N and() {
      return (N) PodGroupFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
